<?php

declare(strict_types=1);

namespace Dedi\SyliusStockHistoryPlugin\Resolver\Order\Api;

use Dedi\SyliusStockHistoryPlugin\Enum\InventoryLogEntryType;
use Dedi\SyliusStockHistoryPlugin\Resolver\Order\InventoryLogOrderResolverInterface;
use Sylius\Component\Core\Model\OrderInterface;
use Sylius\Component\Core\Repository\OrderRepositoryInterface;
use Symfony\Component\HttpFoundation\RequestStack;

class PaymentCompleteResolver implements InventoryLogOrderResolverInterface
{
    public function __construct(
        private readonly RequestStack $requestStack,
        private readonly OrderRepositoryInterface $orderRepository,
    ) {
    }

    public function resolve(string $type): ?OrderInterface
    {
        if (!$this->supports($type)) {
            return null;
        }

        $request = $this->requestStack->getCurrentRequest();

        if (null === $request) {
            return null;
        }

        $path = $request->getPathInfo();

        if (1 === preg_match('/^\/api\/v[0-9]+\/admin\/payments\/([0-9]+)\/complete$/', $path, $matches)) {
            $orderId = $matches[1];
            /** @var ?OrderInterface $order */
            $order = $this->orderRepository->find($orderId);

            return $order;
        }

        return null;
    }

    public function supports(string $type): bool
    {
        return $type === InventoryLogEntryType::API_PAYMENT_COMPLETE->value;
    }
}
